#gnms gemspec

$:.unshift File.expand_path(File.join(File.dirname(__FILE__), 'lib'))
require 'version'

class GnmsGemspecHelper
  def self.remove_gitignored_files(filelist)
    gitignore_file = File.expand_path("../.gitignore", __FILE__)
    if File.exist?(gitignore_file)
      ignores = File.readlines(gitignore_file)
      ignores = ignores.select {|ignore| ignore.chomp.strip != "" and ignore !~ /^#/}
      ignores = ignores.map {|ignore| Regexp.new(ignore.chomp.gsub(".", "\\.").gsub("*", ".*"))}
      r = filelist.select {|fn| not ignores.any? {|ignore| fn =~ ignore }}
      r.select {|fn| fn !~ /\.git/ }
    else
      filelist
    end
  end
  
  def self.remove_matching_files(list, string)
    list.reject {|entry| entry.include?(string)}
  end

  def self.gem_manifest
    r = %w(LICENSE README gnms.gemspec) +
                            Dir.glob("bin/gnms") +
                            Dir.glob("pixmap/**/*") +
                            Dir.glob("sound/*") +
                            remove_gitignored_files(Dir.glob("lib/**/*")) +
                            remove_gitignored_files(Dir.glob("plugins/**/*"))
  end
end

Gem::Specification.new do |s|
  s.name        = "gnms"
  s.version     = GNMSVERSION
  #s.version     = "#{GNMSVERSION}.rc2"
  s.platform    = Gem::Platform::RUBY
  s.required_ruby_version = '>= 1.8.6'
  s.authors     = ["David Maciejak"]
  s.email       = ["david.maciejak@gmail.com"]
  s.homepage    = "http://gnms.rubyforge.org/"
  s.rubyforge_project = "gnms"
  s.summary     = "Gnome Network Management System"
  s.description = "GNMS is a graphical tool used to monitor state of network elements"
 
  s.files       = GnmsGemspecHelper.gem_manifest
  s.has_rdoc    = false 
  s.test_files  = (s.files & Dir['test/*'])
  s.license     = "GPL-2.1"
  
  s.executables  = ["gnms"]
  s.require_path = 'lib'

  s.add_dependency("facter")
  s.add_dependency("goocanvas")
  s.add_dependency("gdk_pixbuf2", ">= 1.1.7")
  s.add_dependency("glib2", ">= 1.1.7")
  s.add_dependency("gtk2", ">= 1.1.7")
  s.add_dependency("net-ssh")
  s.add_dependency("snmp")
  s.add_dependency("xmpp4r")
  s.add_dependency("sqlite3")
  s.add_dependency("pcaprub", ">= 0.11.3")
  s.add_dependency("packetfu")
  s.add_dependency("gruff")
#  s.add_dependency("ruby-ldap")  
#  s.add_dependency("gstreamer")
end

